//
//  WTInternalRenderingViewController.m
//  Native Examples
//
//  Created by Andreas Schacherbauer on 29/07/15.
//  Copyright (c) 2015 Wikitude. All rights reserved.
//

#import "WTInternalRenderingViewController.h"

#import <WikitudeNativeSDK/WikitudeNativeSDK.h>

#import "WikitudeLicense.h"
#import "StrokedRectangle.h"
#import "ExternalRenderer.h"


@interface WTInternalRenderingViewController () <WTWikitudeNativeSDKDelegate, WTClientTrackerDelegate>

@property (nonatomic, strong) WTWikitudeNativeSDK                           *wikitudeSDK;
@property (nonatomic, strong) WTClientTracker                               *clientTracker;

@property (nonatomic, strong) WTEAGLView                                    *wikitudeEAGLView;
@property (nonatomic, strong) WTRenderer                                    *wikitudeRenderer;

@property (nonatomic, assign) BOOL                                          isTracking;

@property (nonatomic, strong) StrokedRectangle                              *renderableRectangle;

@end

@implementation WTInternalRenderingViewController

#pragma mark UIViewController

- (void)viewDidLoad
{
    [super viewDidLoad];
    
    self.renderableRectangle = [[StrokedRectangle alloc] init];
    self.renderableRectangle.scale = 320.0f;
    
    self.wikitudeSDK = [[WTWikitudeNativeSDK alloc] initWithRenderingMode:WTRenderingMode_Internal delegate:self];
    [self.wikitudeSDK setLicenseKey:kWTLicenseKey];
    
    self.wikitudeRenderer = [self.wikitudeSDK createRenderer];
    self.wikitudeEAGLView = [self.wikitudeSDK createEAGLView];
    
    [self.wikitudeEAGLView setRenderer:self.wikitudeRenderer];
    
    [self.view addSubview:self.wikitudeEAGLView];
    [self.wikitudeEAGLView setTranslatesAutoresizingMaskIntoConstraints:NO];
    
    NSDictionary *views = NSDictionaryOfVariableBindings(_wikitudeEAGLView);
    [self.view addConstraints:[NSLayoutConstraint constraintsWithVisualFormat:@"|[_wikitudeEAGLView]|" options:0 metrics:nil views:views]];
    [self.view addConstraints:[NSLayoutConstraint constraintsWithVisualFormat:@"V:|[_wikitudeEAGLView]|" options:0 metrics:nil views:views]];
}

- (void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:animated];
    
    [self.wikitudeSDK start:nil completion:^(BOOL isRunning, NSError * __nonnull error) {
        if ( !isRunning ) {
            NSLog(@"Wikitude SDK is not running. Reason: %@", [error localizedDescription]);
        }
        else
        {
            NSURL *clientTrackerURL = [[NSBundle mainBundle] URLForResource:@"magazine" withExtension:@"wtc" subdirectory:@"Assets"];
            self.clientTracker = [self.wikitudeSDK.trackerManager createClientTrackerFromURL:clientTrackerURL extendedTargets:nil andDelegate:self];
        }
    }];
}

- (void)viewDidDisappear:(BOOL)animated
{
    [super viewDidDisappear:animated];
    
    [self.wikitudeSDK stop];
}

- (void)viewWillTransitionToSize:(CGSize)size withTransitionCoordinator:(id<UIViewControllerTransitionCoordinator>)coordinator
{
    [super viewWillTransitionToSize:size withTransitionCoordinator:coordinator];
    
    [self.wikitudeSDK shouldTransitionToSize:size withTransitionCoordinator:coordinator];
}

- (void)viewDidLayoutSubviews
{
    [super viewDidLayoutSubviews];
    [self.wikitudeSDK shouldTransitionToSize:self.view.bounds.size withTransitionCoordinator:nil];
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

#pragma mark - Delegation
#pragma mark WTWikitudeNativeSDKDelegte
- (WTCustomUpdateHandler)wikitudeNativeSDKNeedsExternalUpdateHandler:(WTWikitudeNativeSDK * __nonnull)wikitudeNativeSDK
{
    /* Intentionally returning a nil handler here */
    return ^(){};
}

- (WTCustomDrawHandler)wikitudeNativeSDKNeedsExternalDrawHandler:(WTWikitudeNativeSDK * __nonnull)wikitudeNativeSDK
{
    return ^(){
        if ( _isTracking ) {
            [self.renderableRectangle drawInContext:[EAGLContext currentContext]];
        }
    };
}

- (void)wikitudeNativeSDK:(WTWikitudeNativeSDK * __nonnull)wikitudeNativeSDK didEncounterInternalError:(NSError * __nonnull)error
{
    NSLog(@"Internal Wikitude SDK error encounterd. %@", [error localizedDescription]);
}

#pragma mark WTClientTrackerDelegate

- (void)baseTracker:(nonnull WTBaseTracker *)baseTracker didRecognizedTarget:(nonnull WTImageTarget *)recognizedTarget
{
    NSLog(@"recognized target '%@'", [recognizedTarget name]);
    _isTracking = YES;
}

- (void)baseTracker:(nonnull WTBaseTracker *)baseTracker didTrackTarget:(nonnull WTImageTarget *)trackedTarget
{
    [self.renderableRectangle setProjectionMatrix:trackedTarget.projection];
    [self.renderableRectangle setModelViewMatrix:trackedTarget.modelView];
}

- (void)baseTracker:(nonnull WTBaseTracker *)baseTracker didLostTarget:(nonnull WTImageTarget *)lostTarget
{
    NSLog(@"lost target '%@'", [lostTarget name]);
    _isTracking = NO;
}


- (void)clientTracker:(nonnull WTClientTracker *)clientTracker didFinishedLoadingTargetCollectionFromURL:(nonnull NSURL *)URL
{
    NSLog(@"Client tracker loaded");
}

- (void)clientTracker:(nonnull WTClientTracker *)clientTracker didFailToLoadTargetCollectionFromURL:(nonnull NSURL *)URL withError:(nonnull NSError *)error
{
    NSLog(@"Unable to load client tracker. Reason: %@", [error localizedDescription]);
}

@end
