//
//  WTTrackerManager.h
//  WikitudeNativeSDK
//
//  Created by Andreas Schacherbauer on 28/04/15.
//  Copyright (c) 2015 Wikitude. All rights reserved.
//

#import <Foundation/Foundation.h>


NS_ASSUME_NONNULL_BEGIN

@class WTBaseTracker;
@class WTClientTracker;
@protocol WTClientTrackerDelegate;
@class WTCloudTracker;
@protocol WTCloudTrackerDelegate;

/**
 * WTTrackerManger provides factory methods to create certain tracker objects.
 */
@interface WTTrackerManager : NSObject

/**
 * @brief Returns a weak pointer to a newly created WTClientTracker object.
 *
 * @discussion Callers need to make sure to retain the reference count e.g. by assigning to a strong property.
 *
 * @param clientTrackerURL A URL from where the client tracker should be loaded from. Client tracker can be loaded from the application bundle or a remote server.
 * @param extendedTargets An array containing string objects where each one of them represents an image target that should be tracked as extended target.
 * @param delegate A object that conforms to the WTClientTrackerDelegate protocol.
 * @return WTClientTracker * A pointer to a newly created WTClientTracker object.
 */
- (WTClientTracker *)createClientTrackerFromURL:(nonnull NSURL *)clientTrackerURL extendedTargets:(nullable NSArray *)extendedTargets andDelegate:(nonnull id<WTClientTrackerDelegate>)delegate;

/**
 * @brief Returns a weak pointer to a newly created WTCloudTracker object.
 *
 * @discussion Callers need to make sure to retian the reference count e.g. by assigning to a strong property.
 *
 * @param authenticationToken The client token that is associated with your Wikitude cloud recogniition account.
 * @param targetCollectionId An identifier which target collection should be loaded on the Wikitude cloud recognition server.
 * @param extendedTargets An array containing string objects where each one of them represents an image target that should be tracked as extended target.
 * @param delegate A object that conforms to the WTCloudTrackerDelegate protocol.
 * @return WTCloudTracker * A pointer to anewly created WTCloudTracker object.
 */
- (WTCloudTracker *)createCloudTrackerWithToken:(nonnull NSString *)authenticationToken targetCollectionId:(nonnull NSString *)targetCollectionId extendedTargets:(nullable NSArray *)extendedTargets andDelegate:(id<WTCloudTrackerDelegate>)delegate;

@end

NS_ASSUME_NONNULL_END
